# uPip's changelog

## Version 0.1.0
Release date : 2024/08/08<br>

First package version.

<b>Statistics</b>
- Package size: 10 ko
- Number of files: 3
- Available distributions: `py3-none-any.whl` and `tar.gz`
- Available functions in the CLI: 8
- Compatible Python versions: `>=3.8`